diff src/plugins/plugin_xep_0047.py @ 391:c34fd9d6242e

spelling
author Goffi <goffi@goffi.org>
date Thu, 29 Sep 2011 14:59:14 +0200
parents 6ff50d609b16
children 8f3551ceee17
line wrap: on
line diff
--- a/src/plugins/plugin_xep_0047.py	Thu Sep 29 14:43:33 2011 +0200
+++ b/src/plugins/plugin_xep_0047.py	Thu Sep 29 14:59:14 2011 +0200
@@ -101,7 +101,7 @@
             failure_cb(sid, file_obj, NS_IBB, failure_reason)
     
     def getProgress(self, sid, data):
         """Fill data with position of current transfert"""
         try:
             file_obj = self.current_stream[sid]["file_obj"]
             data["position"] = str(file_obj.tell())
@@ -134,11 +134,11 @@
         sid = open_elt.getAttribute('sid')
         stanza = open_elt.getAttribute('stanza', 'iq')
         if not sid or not block_size or int(block_size)>65535:
-            warning(_("malformed IBB transfert: %s" % IQ['id']))
+            warning(_("malformed IBB transfer: %s" % IQ['id']))
             self.sendNotAcceptableError(IQ['id'], IQ['from'], xmlstream)
             return
         if not sid in self.current_stream:
-            warning(_("Ignoring unexpected IBB transfert: %s" % sid))
+            warning(_("Ignoring unexpected IBB transfer: %s" % sid))
             self.sendNotAcceptableError(IQ['id'], IQ['from'], xmlstream)
             return
         if self.current_stream[sid]["from"] != jid.JID(IQ['from']):
@@ -101,7 +101,7 @@
     
     def getProgress(self, sid, data):
-        """Fill data with position of current transfert"""
+        """Fill data with position of current transfer"""
         try:
             file_obj = self.current_stream[sid]["file_obj"]